Exception: Protege::InvalidModelError

Inherits:
Error
  • Object
show all
Defined in:
lib/protege/errors/invalid_model_error.rb

Overview

the configured model is not recognized by the provider

Constant Summary

Constants inherited from Error

Error::PERMANENT, Error::TRANSIENT

Instance Method Summary collapse

Constructor Details

#initialize(detail = nil) ⇒ InvalidModelError

Returns a new instance of InvalidModelError.



6
# File 'lib/protege/errors/invalid_model_error.rb', line 6

def initialize(detail = nil) = super(detail || 'the configured model is not recognized by the provider')