Class: Protege::LoopRunEnqueuedEvent

Inherits:
Event
  • Object
show all
Defined in:
lib/protege/events/loop_run_enqueued_event.rb

Overview

Fired when a scheduled responsibility run is recorded pending and enqueued, before a worker picks it up (the Loop layer).

Instance Attribute Summary

Attributes inherited from Event

#payload

Instance Method Summary collapse

Methods inherited from Event

#[], all, channel, #correlation_id, emit, #initialize, subscribe

Constructor Details

This class inherits a constructor from Protege::Event

Instance Method Details

#nameObject



9
# File 'lib/protege/events/loop_run_enqueued_event.rb', line 9

def name         = self[:name]

#persona_nameObject



10
# File 'lib/protege/events/loop_run_enqueued_event.rb', line 10

def persona_name = self[:persona_name]